///
/// @file
///
/// @brief This file contains StarNEig library configuration.
///
/// @author Mirko Myllykoski (mirkom@cs.umu.se), Umeå University
///
/// @internal LICENSE
///
/// Copyright (c) 2019-2020, Umeå Universitet
///
/// Redistribution and use in source and binary forms, with or without
/// modification, are permitted provided that the following conditions are met:
///
/// 1. Redistributions of source code must retain the above copyright notice,
///    this list of conditions and the following disclaimer.
///
/// 2. Redistributions in binary form must reproduce the above copyright notice,
///    this list of conditions and the following disclaimer in the documentation
///    and/or other materials provided with the distribution.
///
/// 3. Neither the name of the copyright holder nor the names of its
///    contributors may be used to endorse or promote products derived from this
///    software without specific prior written permission.
///
/// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
/// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
/// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
/// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
/// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
/// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
/// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
/// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
/// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
/// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
/// POSSIBILITY OF SUCH DAMAGE.
///

#ifndef STARNEIG_CONFIGURATION_H
#define STARNEIG_CONFIGURATION_H

#ifdef __cplusplus
extern "C" {
#endif

///
/// @defgroup starneig_conf Library configuration
///
/// @brief Configuration of the installed library.
///
/// @{
///

///
/// @brief StarNEig major version.
///
#define STARNEIG_VERSION_MAJOR 0

///
/// @brief StarNEig minor version.
///
#define STARNEIG_VERSION_MINOR 2

///
/// @brief StarNEig patch level.
///
#define STARNEIG_VERSION_PATCH 0

///
/// @brief MPI support enabled.
///
/// Defined if the library was compiled with MPI support.
///
/* #undef STARNEIG_ENABLE_MPI */

///
/// @brief CUDA support enabled.
///
/// Defined if the library was compiled with CUDA support.
///
/* #undef STARNEIG_ENABLE_CUDA */

///
/// @brief BLACS support enabled.
///
/// Defined if the library was compiled with ScaLAPACK compatibility layer.
///
/* #undef STARNEIG_ENABLE_BLACS */

///
/// @brief Distributed memory Hessenberg reduction enabled.
///
/// Defined if the starneig_SEP_DM_Hessenberg() function exists.
///
/// @deprecated The STARNEIG_SEP_DM_HESSENBERG precompiler define is deprecated
/// and will be removed in the next release of the library.
///
#define STARNEIG_SEP_DM_HESSENBERG

///
/// @brief Distributed memory Hessenberg-triangular reduction enabled.
///
/// Defined if the starneig_GEP_DM_HessenbergTriangular() function
/// exists.
///
/* #undef STARNEIG_GEP_DM_HESSENBERGTRIANGULAR */

///
/// @brief Full distributed memory reduction enabled.
///
/// Defined if the starneig_SEP_DM_Reduce() function exists.
///
/// @deprecated The STARNEIG_SEP_DM_REDUCE precompiler define is deprecated and
/// will be removed in the next release of the library.
///
#define STARNEIG_SEP_DM_REDUCE

///
/// @brief Full distributed memory generalized reduction enabled.
///
/// Defined if the starneig_GEP_DM_Reduce() function exists.
///
/* #undef STARNEIG_GEP_DM_REDUCE */

///
/// @}
///

#ifdef __cplusplus
}
#endif

#endif // STARNEIG_CONFIGURATION_H
